OC.L10N.register(
    "core",
    {
    "Please select a file." : "ກະລຸນາເລືອກຟາຍ",
    "File is too big" : "ຟາຍໃຫຍ່ໂພດ",
    "The selected file is not an image." : "ຟາຍທີ່ເລືອກບໍ່ແມ່ນຮູບ",
    "The selected file cannot be read." : "ຟາຍທີ່ເລືອກບໍ່ສາມາດອ່ານໄດ້",
    "Invalid file provided" : "ຟາຍບໍ່ຖືກຕ້ອງ",
    "No image or file provided" : "ບໍ່ມີຮູບພາບ ຫຼື ຟາຍ",
    "Unknown filetype" : "ບໍ່ຮູ້ປະເພດຂອງຟາຍ",
    "An error occurred. Please contact your admin." : "ຄັດຂ້ອງ ກະລຸນລາຕິດຕໍ່ ທີມບໍລິຫານ",
    "Invalid image" : "ບໍ່ມີຮູບພາບ",
    "No temporary profile picture available, try again" : "ບໍ່ມີຮູບພາບ ຫຼື ຟາຍຊົ່ວຄາວ, ກະລຸນນາ ລອງໃໝ່",
    "No crop data provided" : "ບໍ່ມີຂໍ້ມູນທີຕັດຕໍ່ປ້ອນເຂົ້າ",
    "No valid crop data provided" : "ບໍ່ມີຂໍ້ມູນຕັດຕໍ່ທີຖືກຕ້ອງປ້ອນເຂົ້າ",
    "Crop is not square" : "ການຕັດຕໍ່ບໍ່ເປັນຮູບສີ່ຫຼຽມ",
    "State token does not match" : "ສະຖານະຂອງໂຕກເກັນບໍ່ຕົງກັນ",
    "Invalid app password" : "ລະຫັດຜ່ານບໍ່ຖືກຕ້ອງ",
    "Could not complete login" : "ບໍ່ສາມາດເຂົ້າລະບົບໄດ້",
    "Your login token is invalid or has expired" : "ໂຕກເກັນເຂົ້າລະບົບບໍ່ຖືກຕ້ອງ ຫຼື ໝົດອາຍຸ",
    "Password reset is disabled" : "ບໍ່ສາມາດປ່ຽນລະຫັດຜ່ານ",
    "%s password reset" : " ປ່ຽນລະຫັດຜ່ານ%s",
    "Password reset" : "ປ່ຽນບະຫັດຜ່ານ",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "ກົດປຸ່ມນີ້ເພື່ອປ່ຽນລະຫັດຜ່ານ. ຖ້າຫາກທ່ານບໍ່ໄດ້ຮ້ອງຂໍການປ່ຽນລະຫັດຜ່ານ, ກະລຸນນາຍົກເລີກ ເມລນີ້. ",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "ກົດປຸ່ມນີ້ເພື່ອປ່ຽນລະຫັດຜ່ານ. ຖ້າຫາກທ່ານບໍ່ໄດ້ຮ້ອງຂໍການປ່ຽນລະຫັດຜ່ານ, ກະລຸນນາຍົກເລີກ ເມລນີ້. ",
    "Reset your password" : "່ປ່ຽນລະຫັດຜ່ານ",
    "Nextcloud Server" : "ເຊີບເວີ ເນັກຄຮາວ",
    "Some of your link shares have been removed" : "ບາງລີ້ງທີທ່ານໄດ້ແບ່ງປັນຖືກຍົກເລີກແລ້ວ",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "ເນື່ອງຈາກບັນຫາດ້ານຄວາມປອດໄພ, ພວກເຮົາໄດ້ຍົກເລິກການແບ່ງປັນລີ້ງ. ສໍາລັບຂໍ້ມູນເພີ່ມເຕີ່ມ ກະລຸນນາກົດເບີ່ງລີງ ",
    "The user limit of this instance is reached." : "ຮອດກໍານົດ ຈໍາກັດຈໍານວນຜູ້ໃຊ້ແລ້ວ",
    "Preparing update" : "ກະກຽມອັບເດດ",
    "[%d / %d]: %s" : "[%d/%d]:%s",
    "Repair step:" : "ຂັ້ນຕອນໃນການປັບປຸງ",
    "Repair info:" : "ຂໍ້ມູນໃນການປັບປຸງ",
    "Repair warning:" : "ຄໍາເຕືອນ ການປັບປຸງ",
    "Repair error:" : "ການປັບປຸງຄັດຂ້ອງ",
    "Please use the command line updater because automatic updating is disabled in the config.php." : "ກະລຸນາໃຊ້ ຄໍາສັ່ງ ປັບປຸງ ເພາະການອັບເດດໂດຍອັດຕະໂນມັດຖືກປິດໃນລະບົບການຕັ້ງຄ່າ config.php.",
    "Turned on maintenance mode" : "ເປີດໂມດການບໍາລຸງຮັກສາ",
    "Turned off maintenance mode" : "ປິດໂມດການບໍາລຸງຮັກສາ",
    "Maintenance mode is kept active" : "ໂມດການບໍາລຸງຮັກສາໄດ້ຖືກເປີດປະໄວ້",
    "Updating database schema" : "ກໍາລັງອັບເດດແຜນຜັງຖານຂໍ້ມູນ",
    "Updated database" : "ຖານຂໍ້ມູນອັບເດດແລ້ວ",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "ກວດເບິ່ງວ່າແຜນຜັງຖານຂໍ້ມູນ ສຳລັບ %s ສາມາດອັບເດດໄດ້ ຫລື ບໍ່ (ມັນອາດໃຊ້ເວລາດົນ ອີງຕາມຂະໜາດ ຂອງຖານຂໍ້ມູນ)",
    "Updated \"%1$s\" to %2$s" : "ອັບເດດ \"%1$s\" ຫາ %2$s",
    "Set log level to debug" : "ກໍານົດລະດັບຂອງ Log ເພື່ອແກ້ຈຸດບົກຜ່ອງ",
    "Reset log level" : "ຕັ້ງລະດັບ Log ຄືນໃໝ່",
    "Starting code integrity check" : "ເລີ່ມຕົ້ນກວດສອບຄວາມສົມບູນຂອງລະຫັດ",
    "Finished code integrity check" : "ສໍາເລັດກວດສອບຄວາມສົມບູນຂອງລະຫັດ",
    "%s (incompatible)" : "%s (ຂັດແຍ້ງ)",
    "The following apps have been disabled: %s" : "ແອັບດັ່ງກ່າວໄດ້ຖືກປີດໄວ້:%s",
    "Already up to date" : "ໄດ້ອັບເດດແລ້ວ",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "ເວັບເຊີບເວີ ຂອງທ່ານຍັງບໍ່ຖືກຕັ້ງຄ່າຢ່າງຖືກຕ້ອງເພື່ອອະນຸຍາດໃຫ້ຟາຍເອກະສານກົງກັນ, ເພາະວ່າອິນເຕີເຟດ WebDAV ອາດຖືກທໍາລາຍ ",
    "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}." : "ເວັບໄຊຂອງທ່ານບໍ່ໄດ້ຖືກຕິດຕັ້ງຢ່າງຖືກຕ້ອງ  ເພື່ອແກ້ ໄຂ \"{url}\" . ຂໍ້ມູນເພີ່ມເຕີມສາມາດເບິ່ງໄດ້ໃນເອກະສານ {linkstart}↗{linkend}.",
    "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "ເວັບໄຊຂອງທ່ານບໍ່ໄດ້ຕິດຕັ້ງຢ່າງຖືກຕ້ອງ ເພື່ອແກ້ ໄຂ \"{url}\" . ກ່ຽວຂ້ອງກັບການຕັ້ງຄ່າເວັບໄຊທີ່ບໍ່ມີການປັບປຸງເພື່ອສົ່ງໂຟນເດີນີ້ໂດຍກົງ. ກະລຸນາປຽບທຽບການຕັ້ງຄ່າຂອງທ່ານກັບກົດລະບຽບການຂຽນຄືນທີ່ຖືກສົ່ງໃນ \".htaccess\" ສໍາລັບ Apache ຫຼື ທີ່ສະຫນອງໃນເອກະສານສໍາລັບ Nginx ທີ່ມັນເປັນ {linkstart}ຫນ້າເອກະສານ↗{linkend}. ໃນ Nginx ເຫຼົ່ານັ້ນໂດຍປົກກະຕິແລ້ວແມ່ນເລີ່ມຕົ້ນດ້ວຍ \"ສະຖານທີ່ ~\" ທີ່ຕ້ອງການການປັບປຸງ.",
    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "ເວັບ ໄຊຂອງທ່ານບໍ່ໄດ້ ຕິດຕັ້ງຢ່າງຖືກຕ້ອງເພື່ອສົ່ງຟາຍ ໌.woff2 . ໂດຍປົກກະຕິແລ້ວແມ່ນບັນຫາທີ່ມີການຕັ້ງຄ່າ Nginx. ສໍາລັບ Nextcloud 15 ມັນຈໍາເປັນຕ້ອງມີການປັບຕົວເພື່ອສົ່ງຟາຍ .woff2 ອີກດ້ວຍ. ປຽບທຽບການຕັ້ງຄ່າ Nginx ຂອງທ່ານກັບການຕັ້ງຄ່າທີ່ ແນະນໍາໃນເອກະສານ {linkstart} ຂອງພວກເຮົາ ↗{linkend}.",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP ບໍ່ໄດ້ຮັບການຕັ້ງຄ່າຢ່າງເຫມາະສົມເພື່ອສອບຖາມຕົວແປສະພາບແວດລ້ອມຂອງລະບົບ. ການທົດສອບກັບ getenv(\"PATH\") ພຽງແຕ່ກັບຄືນການຕອບສະຫນອງທີ່ຫວ່າງເປົ່າ.",
    "Please check the {linkstart}installation documentation ↗{linkend} for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm." : "ກະລຸນາກວດເບິ່ງເອກະສານການຕິດຕັ້ງ {linkstart}↗{linkend} ສໍາລັບບັນທຶກການຕັ້ງຄ່າ PHP ແລະ ການຕັ້ງຄ່າ PHP ຂອງ server ຂອງທ່ານ, ໂດຍສະເພາະເມື່ອໃຊ້ php-fpm.",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "ການຕັ້ງຄ່າແບບອ່ານເທົ່ານັ້ນໄດ້ຖືກເປີດໃຊ້. ການຕັ້ງຄ່າປ້ອງກັນບາງຢ່າງຜ່ານເວັບໄຊ. ຍິ່ງໄປກວ່ານັ້ນ, ຟາຍຈໍາເປັນຕ້ອງໄດ້ຂຽນດ້ວຍມືສໍາລັບທຸກໆການປັບປຸງ.",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "ຖານຂໍ້ມູນຂອງທ່ານບໍ່ສາມາດດຳເນີນການກັບ \"READ COMMITTED”. ປະເພດການເຮັດທຸລະກຳລະດັບນີ້ “ ຊື່ງອາດເຮັດໃຫ້ເກີດບັນຫາ ໃນເວລາ ເປີດການປະຕິບັດການຫຼາຍ ລາຍການພ້ອມກັນ.",
    "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "ໂມດູນ PHP \"fileinfo\" ຫາຍໄປ. ແນະນຳ ໃຫ້ເປີດໃຊ້ໂມດູນນີ້ ເພື່ອໃຫ້ ໄດ້ຜົນທີ່ດີທີ່ສຸດ ເມື່ອຮ່ວມການກວດກາ MIME",
    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems. See the {linkstart}documentation ↗{linkend} for more information." : "ການລັອກຟາຍ ທຸລະກຳ ແມ່ນຖືກປິດ, ອາດຈະນໍາໄປສູ່ບັນຫາຈຳເເນກ. ເຮັດໃຫ້ \"filelocking.enabled\" ໃນ config.php ເພື່ອຫຼີກເວັ້ນບັນຫາເຫຼົ່ານີ້. ເບິ່ງ{linkstart}ເອກະສານ ↗{linkend} ສໍາລັບຂໍ້ມູນເພີ່ມເຕີມ.",
    "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective {linkstart}ISO 3166-1 code ↗{linkend} of the region to your config file." : "ການຕິດຕັ້ງຂອງທ່ານບໍ່ໄດ້ກໍານົດເຂດບໍລິການໂທລະສັບ. ນີ້ແມ່ນຈໍາເປັນເພື່ອຢັ້ງຢືນເບີໂທລະສັບໃນການຕັ້ງຄ່າໂປຟາຍ ທີບໍ່ມີລະຫັດປະເທດ. ເພື່ອອະນຸຍາດ ເລກໝາຍ ທີ່ບໍ່ມີລະຫັດປະເທດ, ກະລຸນາເພີ່ມ \"ກໍານົດເຂດບໍລິການໂທລະສັບ\" ທີ່ມີລະຫັດ {linkstart}ລະຫັດ ISO 3166-1 ↗{linkend} ເຂດພື້ນທີ່ໃສ່ຟາຍ config ຂອງທ່ານ.",
    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "ເປັນໄປບໍ່ໄດ້ ທີ່ຈະດໍາເນີນງານcron ຜ່ານ CLI ໄດ້ . ຂໍ້ຜິດພາດທາງດ້ານເຕັກນິກໄດ້ປາກົດຂື້ນ:",
    "Last background job execution ran {relativeTime}. Something seems wrong. {linkstart}Check the background job settings ↗{linkend}." : "ການປະຕິບັດວຽກງານພື້ນຖານຄັ້ງສຸດທ້າຍໄດ້ ດຳເນີນ {relativeTime}. ມີ{linkstart} ບາງຢ່າງຜິດ,  ກວດສອບການຕັ້ງຄ່າ↗{linkend}ພື້ນຖານ ",
    "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the {linkstart}documentation ↗{linkend}." : "ບໍ່ມີການຕັ້ງຄ່າ cache ຄວາມຈໍາ. ເພື່ອເພີ່ມປະສິດທິພາບ, ກະລຸນາຕັ້ງຄ່າ memcache, ຖ້າມີ. ຂໍ້ມູນເພີ່ມເຕີມສາມາດເບິ່ງໄດ້ໃນ {linkstart} ເອກະສານ ↗{linkend}.",
    "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the {linkstart}documentation ↗{linkend}." : "ບໍ່ມີແຫລ່ງທີ່ເຫມາະ ສົມສໍາລັບການສູມເອົາ ທີ່ພົບໂດຍ PHP ຊຶ່ງເຫດຜົນຄວາມປອດ ໄພ . ຂໍ້ມູນເພີ່ມເຕີມສາມາດເບິ່ງໄດ້ໃນ{linkstart}ເອກະສານ ↗{linkend}.",
    "You are currently running PHP {version}. Upgrade your PHP version to take advantage of {linkstart}performance and security updates provided by the PHP Group ↗{linkend} as soon as your distribution supports it." : "ປະຈຸບັນທ່ານກໍາລັງດໍາເນີນການ PHP {version}. ອັບເດດລຸ້ນ PHP ຂອງທ່ານເພື່ອໃຊ້ ປະສິດທິພາບ {linkstart}  ແລະ ການປັບປຸງຄວາມປອດໄພທີ່ສະຫນອງໃຫ້ໂດຍກຸ່ມ↗{linkend}  PHP ທັນທີທີ່ການແຈກຢາຍຂອງທ່ານສະຫນັບສະຫນູນມັນ.",
    "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud. Further information can be found in the {linkstart}documentation ↗{linkend}." : "ການຕັ້ງຄ່າຫົວຂໍ້ proxy ກັບຄືນບໍ່ຖືກຕ້ອງ, ຫຼື ທ່ານກໍາລັງເຂົ້າເຖິງ Nextcloud ຈາກ proxy ທີ່ເຊື່ອຖືໄດ້. ຖ້າບໍ່ດັ່ງນັ້ນ, ນີ້ແມ່ນບັນຫາຄວາມປອດໄພ ແລະ ສາມາດອະນຸຍາດໃຫ້ຜູ້ໂຈມຕີ spoof ທີ່ຢູ່ IP ຂອງພວກເຂົາດັ່ງທີ່ເຫັນໄດ້ກັບ Nextcloud. ຂໍ້ມູນເພີ່ມເຕີມສາມາດເບິ່ງໄດ້ໃນ{linkstart}ເອກະສານ ↗{linkend}.",
    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the {linkstart}memcached wiki about both modules ↗{linkend}." : "cachedຄວາມຈຳ ຖືກຕັ້ງຄ່າ ເປັນ cache ແຈກຢາຍ, ແຕ່ໂມດູນ PHP ທີ່ບໍ່ຖືກຕ້ອງ \"memcache\" ຖືກຕິດຕັ້ງ. OCMemcacheMemcached ສະຫນັບສະຫນູນພຽງແຕ່ \"memcached\" ແລະ ບໍ່ແມ່ນ \"memcache\". ເບິ່ງ {linkstart}memcached wiki ກ່ຽວກັບທັງສອງ↗{linkend}ໂມດູນ ",
    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the {linkstart1}documentation ↗{linkend}. ({linkstart2}List of invalid files…{linkend} / {linkstart3}Rescan…{linkend})" : "ບາງຟາຍບໍ່ໄດ້ຜ່ານການກວດສອບຄວາມເຊື່ຶອຖື. ຂໍ້ມູນເພີ່ມເຕີມກ່ຽວກັບວິທີແກ້ໄຂບັນຫານີ້ສາມາດເບິ່ງໄດ້ໃນ {linkstart1}ເອກະສານ↗{linkend}/({linkstart2}ລາຍການຟາຍ.. {linkend} / {linkstart3}Rescan... {linkend})",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "ບໍ່ມີ ການກໍານົດ ຫນ້າທີ່ PHP \"ກໍານົດເວລາ\". ອາດຈະເຮັດໃຫ້ scripts ຖືກຢຸດກາງ ການດໍາເນີນງານ, ແລະທໍາລາຍການຕິດຕັ້ງຂອງທ່ານ. ເນະນໍາໃຫ້ເປີດນໍາໃຊ້ ການກໍານົດເວລາ.",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "PHP ຂອງທ່ານບໍ່ໄດ້ຮັບການສະຫນັບສະຫນູນ FreeType, ເຮັດໃຫ້ຮູບພາບໜ້າປົກຄວາມຄົມຊັດບໍ່ລະອຽດ ລວມທັງບັນຫາ ການຕັ້ງຄ່າ interface.",
    "Missing index \"{indexName}\" in table \"{tableName}\"." : "ບໍ່ມີຊື່  index \"{indexName}\" ໃນຕາຕະລາງ \"{tableName}\".",
    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "ຖານຂໍ້ມູນຂາດດັດຊະນີບາງຢ່າງບໍ່ເຫັນ. ເນື່ອງຈາກວ່າການເພີ່ມດັດຊະນີໃສ່ຕາຕະລາງໃຫຍ່ອາດຈະໃຊ້ ເວລາດົນ . ໂດຍການດຳເນີນ \"occ db:add-missing-indices\" ດັດຊະນີທີ່ຂາດໄປ ສາມາດເພີ່ມໄດ້ດ້ວຍມືໃນຂະນະທີ່ຕົວຢ່າງຍັງດໍາເນີນການຕໍ່ໄປ. ເມື່ອດັດຊະນີຖືກຕື່ມຄໍາສອບຖາມໃສ່ຕາຕະລາງເຫຼົ່ານັ້ນຕາມປົກກະຕິແລ້ວຈະໄວຂຶ້ນຫຼາຍ.",
    "Missing primary key on table \"{tableName}\"." : "ຂາດລະຫັດເຂົ້າເຖິງຕາຕະລາງ \"{tableName}\".",
    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "ຖານຂໍ້ມູນຂາດລະຫັດບາງຢ່າງ. ເນື່ອງຈາກວ່າການເພີ່ມກະແຈຕົ້ນຕໍໃສ່ ໂຕະໃຫຍ່ ອາດ ຈະໃຊ້ ເວລາດົນນານທີ່ພວກເຂົາເຈົ້າບໍ່ໄດ້ ຖືກຕື່ມໂດຍອັດຕະໂນມັດ . ໂດຍການແລ່ນ \"occ db:add-missing-primary-keys\" ຂາດກະແຈຕົ້ນຕໍເຫຼົ່ານັ້ນສາມາດເພີ່ມໄດ້ດ້ວຍມືໃນຂະນະທີ່ຕົວຢ່າງຍັງດໍາເນີນການຕໍ່ໄປ.",
    "Missing optional column \"{columnName}\" in table \"{tableName}\"." : "ຂາດ column ທາງເລືອກ \"{columnName}\" ໃນຕາຕະລາງ \"{tableName}\".",
    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "ຖານຂໍ້ມູນແມ່ນຂາດບາງ columns ທາງເລືອກ. ເນື່ອງຈາກວ່າການເພີ່ມ columns ໃສ່ ຕາຕະລາງໃຫຍ່ ອາດ ຈະ ໃຊ້ເວລາດົນ ທີ່ບໍ່ໄດ້ຕື່ມໂດຍອັດຕະໂນມັດ ເມື່ອເລືອກ ໄດ້ . ໂດຍການດຳ \"occ db:add-missing-columns\" columns ທີ່ຂາດໄປສາມາດເພີ່ມໄດ້ດ້ວຍມືໃນຂະນະທີ່ຕົວຢ່າງຍັງດໍາເນີນການຕໍ່ໄປ. ເມື່ອມີການເພີ່ມ columns ອາດຈະປັບປຸງການຕອບສະຫນອງ ຫຼື ການໃຊ້ງານ.",
    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "ຕົວຢ່າງເເນະນຳຂາດໂມດູນ PHP,  ສໍາລັບການປັບປຸງ ແລະ ການປະຕິບັດທີ່ດີກວ່າ ນັ້ນ ແມ່ນແນະນໍາໃຫ້ຕິດຕັ້ງ  ",
    "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "ໂມດູນ php-imagick ໃນກໍລະນີນີ້ບໍ່ມີການສະຫນັບສະຫນູນ SVG. ເພື່ອຄວາມສອດຄ່ອງທີ່ດີກວ່າແມ່ນແນະນໍາໃຫ້ຕິດຕັ້ງ.",
    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "SQLite ກໍາລັງຖືກນໍາໃຊ້ເປັນຖານຂໍ້ມູນbackend. ສໍາລັບການຕິດຕັ້ງທີ່ໃຫຍ່ກວ່າ   ພວກເຮົາຂໍແນະນໍາໃຫ້ທ່ານປ່ຽນໄປຫາ backend ຖານຂໍ້ມູນທີ່ແຕກຕ່າງ ກັນ .",
    "This is particularly recommended when using the desktop client for file synchronisation." : "ແນະນໍາໂດຍສະເພາະເມື່ອການນໍາໃຊ້ desktop ລູກຄ້າ  ສໍາລັບການ ຢືນຢັນຟາຍ",
    "The PHP memory limit is below the recommended value of 512MB." : "ຂີດຈໍາກັດຄວາມຈໍາ PHP ແມ່ນຕ່ໍາກວ່າຄ່າທີ່ແນະນໍາຂອງ 512MB.",
    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "ຊອບແວຂອງຜູ້ ໃຊ້ແຕກຕ່າງຈາກເວັບໄຊ  . ອາດຢູ່ເປັນກໍລະນີ ການຕິດຕັ້ງແອັບພລິເຄຊັນດ້ວຍມື. ກວດສອບການອະນຸຍາດຂອງແອັບພລິເຄຊັນດັ່ງຕໍ່ໄປນີ້:",
    "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL. For further details read {linkstart}the documentation page about this ↗{linkend}." : "MySQL ຖືກນໍາໃຊ້ເປັນຖານຂໍ້ມູນແຕ່ບໍ່ສະຫນັບສະຫນູນຕົວອັກສອນ 4 byte. ເພື່ອ ໃຫ້ ສາມາດຮັບ 4-byteໄດ້(ເຊັ່ນ emojis) ໂດຍບໍ່ມີບັນຫາໃນຊື່ຟາຍ ຫຼື ຄໍາ ເຫັນຍົກຕົວຢ່າງ ແນະນໍາໃຫ້ ເຮັດໃຫ້ ການສະຫນັບສະຫນູນ 4 byte ໃນ MySQL . ສໍາລັບລາຍລະອຽດ ເພີ່ມເຕີມອ່ານ {linkstart} ຫນ້າ ເອກະສານກ່ຽວກັບ ↗{linkend} ນີ້.",
    "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GB of free space available in the temp directory of PHP. Check the logs for full details about the path and the available space. To improve this please change the temporary directory in the php.ini or make more space available in that path." : "ຕົວຢ່າງນີ້ໃຊ້  S3 ເປັນການເກັບກໍາຂໍ້ມູນຕົ້ນຕໍ. ຟາຍອັບໂຫຼດໄດ້ເກັບ ໄວ້ ຊົ່ວ ຄາວ ຢູ່ ໃນ server ແລະ ດັ່ງນັ້ນຈຶ່ງແນະນໍາໃຫ້ມີ ພຶນທີ່ວ່າງ 50 GB ໃນ directory temp ຂອງ PHP . ກວດເບິ່ງບັນຊີລາຍລະອຽດກ່ຽວກັບຊ່ອງທາງ ແລະ  ພຶນທີ່ວ່າງ  . ເພື່ອປັບປຸງກະລຸນາປ່ຽນ directory ຊົ່ວຄາວໃນ php.ini ຫຼື ເຮັດໃຫ້ມີຊ່ອງຫວ່າງຫຼາຍຂຶ້ນໃນຊ່ອງທາງນັ້ນ.",
    "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This most likely means that you are behind a reverse proxy and the overwrite config variables are not set correctly. Please read {linkstart}the documentation page about this ↗{linkend}." : "ທ່ານກໍາລັງເຂົ້າເຖິງຕົວຢ່າງຂອງທ່ານ ກ່ຽວກັບການຕິດຕໍ່ທີ່ປອດໄພ , ເຖິງຢ່າງໃດ ກໍ ຕາມ ຕົວຢ່າງຂອງ ທ່ານແມ່ນການສ້າງ URLs ບໍ່ ຫມັ້ນ ຄົງ . ຫມາຍຄວາມວ່າທ່ານຢູ່ເບື້ອງຫຼັງ proxy reverse ແລະ ຕົວປ່ຽນໃນconfig overwrite ບໍ່ຖືກຕ້ອງ. ກະລຸນາອ່ານ {linkstart}ຫນ້າເອກະສານກ່ຽວກັບ↗{linkend}.",
    "Error occurred while checking server setup" : "ເກີດຂໍ້ຜິດພາດໃນຂະນະທີ່ກວດສອບການຕັ້ງຄ່າ server",
    "For more details see the {linkstart}documentation ↗{linkend}." : "ສໍາລັບລາຍລະອຽດເພີ່ມເຕີມເບິ່ງໃນ {linkstart}ເອກະສານ↗{linkend} ",
    "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "ຫົວຂໍ້ HTTP \"{header}\" ບໍ່ໄດ້ຖືກກໍານົດ \"{expected}\". ນີ້ແມ່ນຄວາມສ່ຽງດ້ານຄວາມປອດໄພ ຫຼື ຄວາມເປັນສ່ວນຕົວທີ່ອາດເປັນໄປໄດ້, ແນະນໍາໃຫ້ປັບການຕັ້ງຄ່ານີ້",
    "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "ຫົວຂໍ້ HTTP \"{header}\" ບໍ່ໄດ້ຖືກກໍານົດ\"{expected}\". ບາງຄຸນລັກສະນະອາດຈະເຮັດວຽກບໍ່ຖືກຕ້ອງ , ແນະນໍາໃຫ້ປັບການຕັ້ງຄ່ານີ້ຕາມທີ່ວາງໄວ້.",
    "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the {linkstart}W3C Recommendation ↗{linkend}." : "ຫົວຂໍ້ \"{header}\" HTTP ບໍ່ໄດ້ກໍານົດ \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" ຫຼື \"{val5}\". ສາມາດເຮັດໃຫ້ຂໍ້ມູນ referer ຮົ່ວ. ເບິ່ງຂໍ້ແນະນໍາ {linkstart}W3C ↗{linkend}.",
    "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the {linkstart}security tips ↗{linkend}." : "ຫົວຂໍ້ \"Strict-Transport-Security\" HTTP ບໍ່ໄດ້ກໍານົດໄວ້ຢ່າງຫນ້ອຍ \"{seconds}\" ວິນາທີ. ສໍາລັບເພີ່ມຄວາມປອດໄພ, ແນະນໍາໃຫ້ເຮັດໃຫ້ HSTS ຕາມທີ່ໄດ້ບັນຍາຍໄວ້ໃນ{linkstart}↗{linkend}ຄໍາແນະນໍາຄວາມປອດໄພ ",
    "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the {linkstart}security tips ↗{linkend}." : "ການເຂົ້າເຖິງເວັບໄຊບໍ່ປອດໄພຜ່ານ HTTP. ທ່ານໄດ້ ຮັບຄໍາແນະນໍາທີ່ ຈະ ຕັ້ງ server ຂອງທ່ານ ເພື່ອ ຮຽກໃຊ້ HTTPS ແທນ , ດັ່ງ ທີ່ ໄດ້ ບັນ ຍາຍ ໃນ {linkstart}↗{linkend} ຄໍາແນະນໍາຄວາມປອດໄພ .",
    "unknown text" : "ຂໍ້ຄວາມທີ່ບໍ່ຮູ້",
    "Hello world!" : "ສະບາຍດີ",
    "sunny" : "ມີເເດດ",
    "Hello {name}, the weather is {weather}" : "ສະບາຍດີ {ຊື່}, ອາກາດແມ່ນ {weather}",
    "Hello {name}" : "ສະບາຍດີ {ຊື່}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>ເຫຼົ່ານີ້ແມ່ນຜົນການຊອກຫາຂອງທ່ານ<script> alert(1)</script></strong>",
    "new" : "ໃໝ່",
    "_download %n file_::_download %n files_" : ["ຟາຍ%n ດາວ ໂຫລດ"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "ການອັບເດດແມ່ນກໍາລັງດໍາເນີນຢູ່, ການອອກຈາກຫນ້ານີ້ອາດຈະຂັດຂວາງຂະບວນການດຳເນີນງານ.",
    "Update to {version}" : "ປັບປຸງ ເປັນ  {version}",
    "An error occurred." : "ເກີດຂໍ້ຜິດພາດ.",
    "Please reload the page." : "ກະລຸນາໂຫຼດຫນ້າເພດອີກ.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "ການປັບປຸງບໍ່ສໍາເລັດ. ສໍາລັບຂໍ້ມູນເພີ່ມເຕີມໃຫ້  <a href=\"{url}\">ກວດສອບການສົ່ງຂໍ້ຄວາມ forum ຂອງ ພວກ ເຮົາ</a>ທີ່ ກ່ຽວ ພັນ ກັບ ບັນ ຫາ ນີ້ .",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "ການປັບປຸງບໍ່ສໍາເລັດ. ກະລຸນາລາຍງານບັນຫານີ້ຕໍ່ <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud.</a>",
    "More apps" : "ແອັບພລິເຄຊັນເພີ່ມເຕີມ",
    "Log in" : "ເຂົ້າລະບົບ",
    "Logging in …" : "ກຳລັງໂຫຼດ",
    "Server side authentication failed!" : "ການຢັ້ງຢືນ Server ລົ້ມເຫຼວ!",
    "Please contact your administrator." : "ກະລຸນາຕິດຕໍ່ຜູ້ຄຸມລະບົບຂອງທ່ານ.",
    "An internal error occurred." : "ເກີດຂໍ້ຜິດພາດພາຍໃນ.",
    "Please try again or contact your administrator." : "ກະລຸນາລອງອີກ ຫຼື ຕິດຕໍ່ຜູ້ຄຸ້ມຄອງລະບົບຂອງທ່ານ.",
    "Password" : "ລະຫັດຜ່ານ",
    "Wrong username or password." : "ຊື່ຜູ້ໃຊ້ ຫຼື ລະຫັດຜ່ານຜິດ.",
    "User disabled" : "ປິດຊື່ຜູ້ໃຊ້",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "ພວກເຮົາກວດພົບຄວາມພະຍາຍາມ login ທີ່ ບໍ່ຖືກຕ້ອງຈາກ IP ຂອງ ທ່ານ . ດັ່ງນັ້ນການເຄື່ອນໄຫວຕໍ່ໄປຂອງທ່ານແມ່ນ throttled ເຖິງ 30 ວິນາທີ.",
    "Username or email" : "ຊື່ຜູ້ໃຊ້ ຫຼື ອີເມວ",
    "Your account is not setup for passwordless login." : "ບັນຊີຂອງທ່ານບໍ່ໄດ້ຕັ້ງຄ່າສໍາລັບການເຂົ້າລະຫັດຜ່ານ.",
    "Passwordless authentication is not supported in your browser." : "ການຢັ້ງຢືນແບບບໍ່ມີລະຫັດຜ່ານບໍ່ໄດ້ຮັບການສະຫນັບສະຫນູນໃນເວັບໄຊຂອງທ່ານ.",
    "Passwordless authentication is only available over a secure connection." : "ການຢັ້ງຢືນແບບບໍ່ມີລະຫັດຜ່ານແມ່ນມີພຽງແຕ່ການເຊື່ອມຕໍ່ທີ່ປອດໄພເທົ່ານັ້ນ.",
    "Reset password" : "ຕັ້ງລະຫັດຄືນໃຫມ່",
    "If it is not there ask your local administrator." : "ຖ້າບໍ່ໄດ້ຖາມຜູ້ເບິ່ງລະບົບຂອງທ່ານ.",
    "Couldn't send reset email. Please contact your administrator." : "ບໍ່ສາມາດຕັ້ງຄ່າສົ່ງອີເມວຄືນ ໄດ້. ກະລຸນາຕິດຕໍ່ຜູ້ເບິ່ງລະບົບຂອງທ່ານ.",
    "Back to login" : "ກັບຄືນເຂົ້າສູ່ລະບົບ",
    "New password" : "ລະຫັດຜ່ານໃຫມ່",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "ເຂົ້າລະຫັດຟາຍຂອງທ່ານ . ຈະບໍ່ໄດ້ຮັບຂໍ້ມູນຂອງທ່ານພາຍຫຼັງ ທີ່ລະຫັດຜ່ານຂອງທ່ານ ໄດ້ຮັບການຕັ້ງຄ່າໃຫມ່ . ຖ້າທ່ານບໍ່ແນ່ໃຈ, ກະລຸນາຕິດຕໍ່ຜູ້ເບິ່ງລະບົບຂອງທ່ານ ກ່ອນທີ່ທ່ານຈະສືບຕໍ່. ທ່ານຕ້ອງການທີ່ຈະສືບຕໍ່ແທ້ໆບໍ?",
    "I know what I'm doing" : "ຂ້ອຍຮູ້ວ່າຂ້ອຍກຳລັງເຮັດຫຍັງຢູ່",
    "Resetting password" : "ການຕັ້ງລະຫັດຄືນໃຫມ່",
    "Recommended apps" : "ແອັບພລິເຄຊັນທີ່ແນະນໍາ",
    "Loading apps …" : "ກຳລັງໂຫຼດເເອັບ",
    "Installing apps …" : "ກໍາລັງຕິດຕັ້ງແອັບ ...",
    "App download or installation failed" : "ການດາວໂຫລດApp ຫຼືການຕິດຕັ້ງຫຼົ້ມເຫລວ",
    "Skip" : "ຂ້າມໄປ",
    "Install recommended apps" : "ຕິດຕັ້ງແອັບທີ່ແນະນໍາ",
    "Schedule work & meetings, synced with all your devices." : "ຕາຕະລາງການເຮັດວຽກ & ການປະຊຸມ, synced ກັບອຸປະກອນທັງຫມົດຂອງທ່ານ.",
    "Keep your colleagues and friends in one place without leaking their private info." : "ຮັກສາເພື່ອນຮ່ວມງານ ແລະ ຫມູ່ ເພື່ອນ ຂອງ ທ່ານ ໄວ້ ໃນບ່ອນດຽວໂດຍບໍ່ໄດ້ ໃຫ້ຂໍ້ ຄວາມ ສ່ວນ ຕົວ ຂອງ ເຂົາ ເຈົ້າຮົ່ວໄຫຼ .",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "ແອັບອີເມວລວມເຂົ້າກັບ ຟາຍຕ່າງໆ, ເບີຕິດຕໍ່ ແລະ ປະຕິທິນ",
    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chatting, ການໂທວິດີໂອ, screen sharing, ການປະຊຸມອອນໄລນ໌ ແລະ ການປະຊຸມເວັບໄຊ – ໃນເວັບໄຊຂອງທ່ານ ແລະ apps ມືຖື.",
    "Forgot password?" : "ລືມລະຫັດຜ່ານ?",
    "Log in with a device" : "ເຂົ້າສູ່ລະບົບດ້ວຍອຸປະກອນ",
    "Back" : "ຫຼັງ",
    "Login form is disabled." : "ຮູບແບບLogin ຖືກປິດ.",
    "Reset search" : "Reset ຄົ້ນຫາ",
    "Search for {name} only" : "ຄົ້ນຫາ {name} ເທົ່ານັ້ນ",
    "No results for {query}" : "ບໍ່ມີຜົນສໍາລັບ {query}",
    "Start typing to search" : "ເລີ່ມພິມເພື່ອຄົ້ນຫາ",
    "Loading more results …" : "ຜົນການດາວໂຫຼດເພີ່ມເຕີມ ...",
    "Load more results" : "ຜົນLoad ເພີ່ມເຕີມ",
    "Search" : "ຄົ້ນຫາ",
    "An error occurred while searching for {type}" : "ເກີດຂໍ້ຜິດພາດໃນຂະນະທີ່ຊອກຫາ {ປະເພດ}",
    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["ກະລຸນາໃສ່ {minSearchLength} ຕົວອັກສອນຫຼືຫຼາຍກວ່ານັ້ນເພື່ອຄົ້ນຫາ"],
    "Search {types} …" : "ຄົ້ນຫາ {ປະເພດ} ...",
    "Settings" : "ການຕັ້ງຄ່າ",
    "Could not load your contacts" : "ບໍ່ສາມາດໂຫຼດການຕິດຕໍ່ຂອງທ່ານ",
    "Search contacts …" : "ຄົ້ນຫາຕິດຕໍ່ ...",
    "No contacts found" : "ບໍ່ພົບຜູ້ຕິດຕໍ່",
    "Show all contacts …" : "ສະແດງການຕິດຕໍ່ທັງຫມົດ ...",
    "Install the Contacts app" : "ຕິດຕັ້ງແອັບ Contacts",
    "Loading your contacts …" : "ກໍາລັງໂຫຼດການຕິດຕໍ່ຂອງທ່ານ ...",
    "Looking for {term} …" : "ຊອກຫາ {term} ...",
    "No" : "ບໍ່",
    "Yes" : "ແມ່ນແລ້ວ",
    "No files in here" : "ບໍ່ມີຟາຍໃນທີ່ນີ້",
    "New folder" : "ໂຟນເດີໃຫມ່",
    "No more subfolders in here" : "ບໍ່ມີ ໂຟນເດີຍ່ອຍ ອີກຕໍ່ໄປໃນນີ້",
    "Name" : "ຊື່",
    "Size" : "ຂະຫນາດ",
    "Modified" : "ດັດແປງ",
    "\"{name}\" is an invalid file name." : "\"{name}\" ແມ່ນຊື່ຟາຍທີ່ບໍ່ຖືກຕ້ອງ.",
    "File name cannot be empty." : "ຊື່ຟາຍບໍ່ໃຫ້ເປົ່າວ່າງ",
    "\"/\" is not allowed inside a file name." : "ບໍ່ອະນຸຍາດໃຫ້\"/\" ຢູ່ໃນຊື່ໄຟລ໌.",
    "\"{name}\" is not an allowed filetype" : "\"{ຊື່}\" ບໍ່ອະນຸຍາດປະເພດແຟ້ມ",
    "{newName} already exists" : "{newName} ມີແລ້ວ",
    "Choose" : "ເລືອກ",
    "Copy" : "ສຳເນົາ",
    "Move" : "ຍ້າຍ",
    "Error loading file picker template: {error}" : "ໂຫຼດຟາຍຕົວຢ່າງຜິດພາດ:{error}",
    "OK" : "ຕົກລົງ",
    "Error loading message template: {error}" : "ການໂຫຼດຂໍ້ຄວາມຜິດພາດ:  {error}",
    "read-only" : "ອ່ານຢ່າງດຽວ",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} ມີບັນຫາ"],
    "One file conflict" : "ມີຟາຍຫນຶ່ງບໍ່ຖືກ",
    "New Files" : "ຟາຍໃຫມ່",
    "Already existing files" : "ຟາຍທີ່ມີຢູ່ແລ້ວ",
    "Which files do you want to keep?" : "ທ່ານຕ້ອງການເກັບຮັກສາຟາຍໃດ?",
    "If you select both versions, the copied file will have a number added to its name." : "ຖ້າທ່ານເລືອກເອົາທັງສອງversions,ຟາຍທີ່ສໍາເນົາຈະມີຈໍານວນເພີ່ມໃສ່ຊື່ຂອງມັນ.",
    "Cancel" : "ຍົກເລີກ",
    "Continue" : "ສືບຕໍ່",
    "(all selected)" : "(ຄັດເລືອກທັງຫມົດ)",
    "({count} selected)" : "({count} ຖືກຄັດເລືອກ)",
    "Error loading file exists template" : "ໂຫຼດຟາຍທີ່ຍັງຢູ່ຜິດພາດ",
    "Pending" : "ທີ່ກໍາລັງລໍຖ້າ",
    "Copy to {folder}" : "ສໍາເນົາໄປຍັງ {ໂຟນເດີ}",
    "Move to {folder}" : "ຍ້າຍໄປ {folder}",
    "Saving …" : "ກຳລັງບັນທຶກ",
    "Authentication required" : "ການຢັ້ງຢືນທີ່ຈໍາເປັນ",
    "This action requires you to confirm your password" : "ການກະທໍານີ້ຮຽກຮ້ອງໃຫ້ທ່ານເພື່ອຢືນຢັນລະຫັດຜ່ານຂອງທ່ານ",
    "Confirm" : "ຢືນຢັນ",
    "Failed to authenticate, try again" : "ບໍ່ສາມາດຮັບຮອງຄວາມຖຶກຕ້ອງໄດ້, ລອງອີກຄັ້ງ",
    "seconds ago" : "ວິນາທີຜ່ານມາ",
    "Connection to server lost" : "ການເຊື່ອມຕໍ່ກັບ server ສູນເສຍ",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["ການໂຫຼດໜ້າເຟສມີບັນຫາ, ການໂຫຼດຄືນໃນ %nວິນາທີ"],
    "Add to a project" : "ເພິ່ມໃສ່ໂຄງການ",
    "Show details" : "ສະແດງລາຍລະອຽດ",
    "Hide details" : "ເຊື່ອງລາຍລະອຽດ",
    "Rename project" : "ປ່ຽນຊື່ໂຄງການ",
    "Failed to rename the project" : "ບໍ່ໄດ້ປ່ຽນຊື່ໂຄງການ",
    "Failed to create a project" : "ບໍ່ໄດ້ສ້າງໂຄງການ",
    "Failed to add the item to the project" : "ບໍ່ສາມາດຕື່ມລາຍການເຂົ້າໃນໂຄງການໄດ້",
    "Connect items to a project to make them easier to find" : "ຕິດຕໍ່ສິ່ງຂອງກັບໂຄງການເພື່ອເຮັດໃຫ້ພວກເຂົາເຈົ້າຊອກຫາໄດ້ງ່າຍ ຂຶ້ນ",
    "Type to search for existing projects" : "ພິມເພື່ອຊອກຫາໂຄງການທີ່ມີຢູ່ແລ້ວ",
    "New in" : "ໃຫມ່",
    "View changelog" : "ເບິ່ງການປ່ຽນແປງ",
    "Very weak password" : "ລະຫັດອ່ອນຫຼາຍ",
    "Weak password" : "ລະຫັດອ່ອນ",
    "So-so password" : "ລະຫັດທຳມະດາ",
    "Good password" : "ລະຫັດຜ່ານ",
    "Strong password" : "ລະຫັດທີ່ເຂັ້ມແຂງ",
    "No action available" : "ບໍ່ມີການກະທໍາທີ່ມີຢູ່",
    "Error fetching contact actions" : "ຜິດພາດໃນການຮັບເອົາການຕິດຕໍ່",
    "Non-existing tag #{tag}" : "ບໍ່ມີtag #{tag}",
    "Invisible" : "ເບິ່ງບໍ່ເຫັນ",
    "Delete" : "ລຶບ",
    "Rename" : "ປ່ຽນຊື່",
    "Collaborative tags" : "tags ການຮ່ວມມື",
    "No tags found" : "ບໍ່ພົບtags",
    "Personal" : "ສ່ວນບຸກຄົນ",
    "Users" : "ຜູ້ໃຊ້",
    "Apps" : "ແອັບພລິເຄຊັນ",
    "Admin" : "ຜູ້ເບິ່ງເເຍງລະບົບ",
    "Help" : "ການຊ່ວຍເຫຼືອ",
    "Access forbidden" : "ຫ້າມການເຂົ້າເຖິງ",
    "Back to %s" : "ຫຼັງ%s",
    "Too many requests" : "ຄໍາຮ້ອງຂໍຫຼາຍເກີນໄປ",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "ມີຄໍາຮ້ອງຂໍຫຼາຍເກີນໄປຈາກເຄືອຂ່າຍຂອງທ່ານ. Retry ໃນເວລາຕໍ່ມາ ຫຼື ຕິດຕໍ່ຜູ້ບໍລິຫານຂອງທ່ານຖ້າຫາກວ່ານີ້ແມ່ນຄວາມຜິດພາດ",
    "Error" : "ຜິດພາດ",
    "Previous" : "ກ່ອນໜ້າ",
    "Internal Server Error" : "ຄວາມຜິດພາດຂອງ Server ພາຍໃນ",
    "The server was unable to complete your request." : "server ບໍ່ສາມາດສໍາເລັດຄໍາຮ້ອງຂໍຂອງທ່ານ",
    "If this happens again, please send the technical details below to the server administrator." : "ຖ້າຫາກວ່ານີ້ເກີດຂຶ້ນອີກ, ກະລຸນາສົ່ງລາຍລະອຽດທາງດ້ານເຕັກນິກຂ້າງລຸ່ມນີ້ໄປຫາຜູ້ບໍລິຫານ server",
    "More details can be found in the server log." : "ລາຍລະອຽດເພີ່ມເຕີມສາມາດເບິ່ງໄດ້ໃນ log server.",
    "Technical details" : "ລາຍລະອຽດເຕັກນິກ",
    "Remote Address: %s" : "ທີ່ຢູ່ ໄລຍະໄກ%s ",
    "Request ID: %s" : "ຂໍຮອງ %s",
    "Type: %s" : "ພິມ%s",
    "Code: %s" : "ລະຫັດ%s",
    "Message: %s" : "ຂໍ້ຄວາມ %s",
    "File: %s" : "ຟາຍ%s",
    "Line: %s" : "ສາຍ: %s",
    "Trace" : "ຕິດຕາມ",
    "Security warning" : "ຄໍາເຕືອນດ້ານຄວາມປອດໄພ",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "ຊອບແວຂໍ້ມູນແລະ ຟາຍ ຂອງ ທ່ານອາດຈະເຂົ້າເຖິງໄດ້ຈາກອິນເຕີເນັດເພາະວ່າຟາຍ .htaccess ບໍ່ໄດ້ຜົນ .",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "ສໍາລັບຂໍ້ມູນວິທີການຕັ້ງຄ່າ server ຂອງທ່ານຢ່າງຖືກຕ້ອງ, ກະລຸນາເບິ່ງ <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">ເອກະສານ</a>",
    "Create an <strong>admin account</strong>" : "ສ້າງ <strong>ບັນຊີ admin</strong>",
    "Username" : "ຊື່ຜູ້ໃຊ້",
    "Show password" : "ສະແດງລະຫັດຜ່ານ",
    "Storage & database" : "ການເກັບກໍາຂໍ້ມູນ & ຖານຂໍ້ມູນ",
    "Data folder" : "ໂຟນເດີຂໍ້ມູນ",
    "Configure the database" : "ຕັ້ງຄ່າຖານຂໍ້ມູນ",
    "Only %s is available." : "ມີແຕ່ %sເທົ່ານັ້ນ.",
    "Install and activate additional PHP modules to choose other database types." : "ຕິດຕັ້ງ ແລະ ເປິດນຳໃຊ້ໂມດູນ PHP ເພີ່ມເຕີມເພື່ອເລືອກປະເພດຖານຂໍ້ມູນອື່ນໆ.",
    "For more details check out the documentation." : "ສໍາລັບລາຍລະອຽດເພີ່ມເຕີມໃຫ້ ກວດເບິ່ງເອກະສານ",
    "Database user" : "ຜູ້ໃຊ້ຖານຂໍ້ມູນ",
    "Database password" : "ລະຫັດຖານຂໍ້ມູນ",
    "Database name" : "ຊື່ຖານຂໍ້ມູນ",
    "Database tablespace" : "ຕາຕະລາງຖານຂໍ້ມູນ",
    "Database host" : "ເຈົ້າພາບຖານຂໍ້ມູນ",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "ກະລຸນາລະບຸເລກ port ພ້ອມກັບຊື່ເຈົ້າພາບ (ເຊັ່ນ: localhost:5432).",
    "Performance warning" : "ຄໍາເຕືອນດ້ານການປະຕິບັດງານ",
    "You chose SQLite as database." : "ທ່ານ ເລືອກ SQLite ເປັນຖານຂໍ້ມູນ.",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite ຄວນໃຊ້ສໍາລັບກໍລະນີທີ່ມີຫນ້ອຍທີ່ສຸດ ແລະ ການພັດທະນາເທົ່ານັ້ນ. ສໍາລັບການຜະລິດພວກເຮົາແນະນໍາ backend ຖານຂໍ້ມູນທີ່ແຕກຕ່າງກັນ.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "ຕິດຕັ້ງແອັບທີ່ແນະນໍາ",
    "Need help?" : "ຕ້ອງການຄວາມຊ່ວຍເຫຼືອ?",
    "See the documentation" : "ເບິ່ງເອກະສານ",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "ເບິ່ງຄືວ່າທ່ານກໍາລັງພະຍາຍາມຕິດຕັ້ງ Nextcloud ຂອງທ່ານຄືນໃຫມ່. ເຖິງ ຢ່າງ ໃດ ກໍ ຕາມ CAN_INSTALLຟາຍ ແມ່ນຂາດໄປຈາກບັນ ຊີການconfig ຂອງ ທ່ານ . ກະລຸນາສ້າງຟາຍ CAN_INSTALL ໃນໂຟນເດີ config ຂອງທ່ານເພື່ອສືບຕໍ່.",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "ບໍ່ສາມາດລຶບ CAN_INSTALL ອອກຈາກໂຟນເດີconfig ໄດ້. ກະລຸນາລຶບໄຟລ໌ນີ້ອອກດ້ວຍມື.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "ຊອບແວນີ້ຕ້ອງ ການ JavaScript ສໍາ ລັບການດໍາເນີນງານ ທີ່ຖືກຕ້ອງ . ກະລຸນາເປິດ {linkstart}  JavaScript {linkend} ແລະ ໂຫຼດຫນ້າເພດຄືນໃໝ່.",
    "Skip to main content" : "ຂ້າມ ໄປຫາເນື້ອຫາຫຼັກ",
    "Skip to navigation of app" : "ຂ້າມໄປຍັງແອັບນຳທາງ",
    "Get your own free account" : "ຮັບບັນຊີຟຣີຂອງທ່ານເອງ",
    "Contacts" : "ຕິດຕໍ່",
    "Contacts menu" : "ເມນູຕິດຕໍ່",
    "Confirm your password" : "ຢືນຢັນລະຫັດຜ່ານຂອງທ່ານ",
    "Connect to your account" : "ເຊື່ອມຕໍ່ບັນຊີຂອງທ່ານ",
    "Please log in before granting %1$s access to your %2$s account." : "ກະລຸນາເຂົ້າລະບົບກ່ອນທີ່ຈະໃຫ້ %1$sການເຂົ້າເຖິງບັນຊີຂອງທ່ານ%2$s.",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "ຖ້າທ່ານບໍ່ໄດ້ພະຍາຍາມທີ່ຈະຕິດຕັ້ງອຸປະກອນຫຼື app ໃຫມ່ , ບາງຄົນພະຍາຍາມຫຼອກລວງ ທ່ານໃຫ້ອະນຸຍາດໃຫ້ເຂົາເຈົ້າເຂົ້າເຖິງຂໍ້ມູນຂອງທ່ານ. ໃນກໍລະນີນີ້ບໍ່ໄດ້ດໍາເນີນການ ແລະ ແທນທີ່ຈະຕິດຕໍ່ຜູ້ບໍລິຫານລະບົບຂອງທ່ານ.",
    "App token" : "ແອັບ token",
    "Grant access" : "ການເຂົ້າເຖິງ Grant",
    "Alternative log in using app token" : "log ທາງເລືອກໃນການນໍາໃຊ້ token app",
    "Account access" : "ການເຂົ້າເຖິງບັນຊີ",
    "You are about to grant %1$s access to your %2$s account." : "ທ່ານກໍາລັງຈະໃຫ້ %1$sການເຂົ້າເຖິງບັນຊີ %2$sຂອງທ່ານ.",
    "Account connected" : "ບັນຊີທີ່ຕິດພັນ",
    "Your client should now be connected!" : "ຕອນນີ້ລູກຄ້າຂອງທ່ານຄວນຈະເຊື່ອມຕໍ່!",
    "You can close this window." : "ທ່ານສາມາດປິດwindowນີ້ໄດ້.",
    "This share is password-protected" : "ການແບ່ງປັນນີ້ແມ່ນການປ້ອງກັນລະຫັດຜ່ານ",
    "Two-factor authentication" : "ຮັບຮອງການຢັ້ງຢືນສອງຄັ້ງ",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "ເພີ່ມທະວີຄວາມປອດໄພໃຫ້ບັນຊີຂອງທ່ານ . ເລືອກປັດໃຈທີສອງສໍາລັບການຢັ້ງຢືນ",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "ບໍ່ສາມາດໂຫຼດໄດ້ ຢ່າງຫນ້ອຍໃຊ້ວິທີການ auth ສອງປັດໃຈຂອງທ່ານ. ກະລຸນາຕິດຕໍ່ admin ຂອງທ່ານ.",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "ການຢັ້ງຢືນສອງປັດໃຈແມ່ນຖືກບັງຄັບໃຊ້ແຕ່ຍັງບໍ່ໄດ້ຖືກຕັ້ງຄ່າໃນບັນຊີຂອງທ່ານ. ຕິດຕໍ່ admin ຂອງທ່ານສໍາລັບການຊ່ວຍເຫຼືອ.",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "ການຢັ້ງຢືນສອງປັດໃຈແມ່ນຖືກບັງຄັບໃຊ້ແຕ່ຍັງບໍ່ໄດ້ຖືກຕັ້ງຄ່າໃນບັນຊີຂອງທ່ານ. ກະລຸນາສືບຕໍ່ຕັ້ງການຢັ້ງຢືນສອງປັດໃຈ.",
    "Set up two-factor authentication" : "ການຕັ້ງຄ່າຮັບຮອງການຢັ້ງຢືນສອງຄັ້ງ",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "ການຢັ້ງຢືນສອງປັດໃຈແມ່ນຖືກບັງຄັບໃຊ້ແຕ່ຍັງບໍ່ໄດ້ຖືກຕັ້ງຄ່າໃນບັນຊີຂອງທ່ານ. ໃຊ້ລະຫັດສໍາຮອງຂອງທ່ານເພື່ອເຂົ້າລະບົບຫຼືຕິດຕໍ່ admin ຂອງທ່ານສໍາລັບການຊ່ວຍເຫຼືອ.",
    "Use backup code" : "ໃຊ້ລະຫັດສໍາຮອງ",
    "Cancel login" : "ຍົກເລີກ login",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "ເພີ່ມທະວີຄວາມປອດໄພແມ່ນຖືກບັງຄັບໃຊ້ ສໍາລັບບັນຊີ ຂອງທ່ານ . ເລືອກຜູ້ໃຫ້ບໍລິການທີ່ກຳນົດໄວ້",
    "Error while validating your second factor" : "ຄວາມຜິດພາດໃນຂະນະທີ່ການຢັ້ງຢືນທີສອງຂອງທ່ານ",
    "Access through untrusted domain" : "ການເຂົ້າເຖິງຜ່ານໂດເມນທີ່ບໍ່ໜ້າເຊື່ຶອຖື",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "ກະລຸນາຕິດຕໍ່ຜູ້ຄຸ້ມຄອງລະບົບຂອງທ່ານ. ຖ້າທ່ານເປັນຜູ້ຄຸ້ມຄອງລະບົບ, ແກ້ໄຂການຕັ້ງຄ່າ \"trusted_domains\" ໃນconfig/config.php ເຊັ່ນຕົວຢ່າງໃນ config.sample.php.",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "ຂໍ້ມູນເພີ່ມເຕີມກ່ຽວກັບວິທີການຕັ້ງຄ່ານີ້ສາມາດເບິ່ງໄດ້ໃນ %1$sເອກະສານ.%2$s",
    "App update required" : "ອັບເດດ App ທີ່ຕ້ອງການ",
    "%1$s will be updated to version %2$s" : " %1$sຈະຖືກປັບປຸງໃຫ້ເປັນລູ້ນ %2$s",
    "The following apps will be updated:" : "ແອັບພລິເຄຊັນດັ່ງຕໍ່ໄປນີ້ຈະໄດ້ຮັບການປັບປຸງ:",
    "These incompatible apps will be disabled:" : "ແອັບພລິເຄຊັນທີ່ບໍ່ສາມາດເຂົ້າກັນໄດ້,  ເຫຼົ່ານີ້ຈະຖືກປິດ:",
    "The theme %s has been disabled." : "ຫົວຂໍ້ %sໄດ້ຖືກປິດ.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "ກະລຸນາໃຫ້ແນ່ໃຈວ່າຖານຂໍ້ມູນ, ໂຟນເດີ config ແລະ ໂຟນເດີຂໍ້ມູນໄດ້ຖືກສໍາຮອງໄວ້ກ່ອນທີ່ຈະດໍາເນີນການ.",
    "Start update" : "ເລີ່ມອັບເດດ",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "ເພື່ອຫຼີກເວັ້ນການໃຊ້ ເວລາທີ່ມີການຕິດຕັ້ງ.  ແທນທີ່ທ່ານສາມາດແລ່ນຄໍາ ສັ່ງດັ່ງຕໍ່ໄປນີ້ຈາກການຕິດຕັ້ງຂອງ ທ່ານໂດຍກົງ :",
    "Detailed logs" : "ບັນທຶກໂດຍລາຍລະອຽດ",
    "Update needed" : "ການປັບປຸງທີ່ຈໍາເປັນ",
    "Please use the command line updater because you have a big instance with more than 50 users." : "ກະລຸນາໃຊ້  ອັບເດດແຖວຄໍາສັ່ງ ເພາະວ່າທ່ານມີຕົວຢ່າງໃຫຍ່ທີ່ມີຜູ້ໃຊ້ຫຼາຍກວ່າ 50 ຜຸ້ໃຊ້.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "ສໍາລັບການຊ່ວຍເຫຼືອ, ເບິ່ງ <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">ເອກະສານ</a>.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "ຂ້າ ພະເຈົ້າຮູ້ວ່າຖ້າຫາກວ່າຂ້າພະເຈົ້າສືບຕໍ່ເຮັດການອັບເດດຜ່ານເວັບ UI ມີຄວາມສ່ຽງ , ວ່າ ຄໍາຮ້ອງດຳເນີນການໝົດເວລາ  ແລະ ອາດຈະເຮັດໃຫ້ການສູນເສຍຂໍ້ມູນ, ແຕ່ຂ້າ ພະເຈົ້າມີການສໍາຮອງ ແລະ ຮູ້ວິທີການກູ້ຄືນ ຕົວຢ່າງ ຂອງຂ້າພະເຈົ້າໃນກໍລະນີທີ່ລົ້ມ ເຫລວ .",
    "Upgrade via web on my own risk" : "ການຍົກລະດັບ ຜ່ານເວັບໄຊໃນຄວາມສ່ຽງຂອງຂ້ອຍເອງ",
    "Maintenance mode" : "ຮູບແບບການບໍາລຸງຮັກສາ",
    "This %s instance is currently in maintenance mode, which may take a while." : "%sຕົວຢ່າງນີ້ໃນປັດຈຸບັນແມ່ນຢູ່ໃນວິທີການບໍາລຸງຮັກສາ, ຊຶ່ງອາດຈະໃຊ້ ເວລາໃນໄລຍະໜຶ່ງ",
    "This page will refresh itself when the instance is available again." : "ຫນ້ານີ້ຈະ refresh ເມື່ອມີຕົວຢ່າງອີກ.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "ຕິດຕໍ່ຜູ້ບໍລິຫານລະບົບຂອງທ່ານຖ້າຫາກວ່າຂ່າວສານນີ້ຍັຢູ່ ຫຼື ປາກົດໂດຍບໍ່ຄາດຄິດ.",
    "Enter your subscription key to increase the user limit. For more information about Nextcloud Enterprise see our website." : "ໃສ່ລະຫັດຜ່ານສະໝັກ ເພື່ອເພີ່ມຂີດຄວາມສາມາດຂອງຜູ້ໃຊ້. ສຳລັບຂໍ້ມູນເພີ່ມເຕີມກ່ຽວກັບ Nextcloud ສາມາດເບິ່ງເວັບໄຊທ໌ຂອງພວກເຮົາ.",
    "[%d / %d]: Checking table %s" : "[%d/%d]:ກວດເບີ່ງຕາຕະລາງ %s",
    "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "ເວັບໄຊ ບໍ່ມີການເຊື່ອມຕໍ່ອິນເຕີເນັດ: ຫຼາຍຈຸດສຸດທ້າຍບໍ່ສາມາດເຂົ້າເຖິງໄດ້. ຫມາຍຄວາມວ່າຄຸນສົມບັດບາງຢ່າງເຊັ່ນການ ຕິດຕັ້ງພື້ນທີເກັບຂໍ້ມູນພາຍນອກ,  ການແຈ້ງເຕືອນ ກ່ຽວກັບການອັບເດດ ຫຼື ການ ຕິດຕັ້ງຂອງ apps ຂອງ ພາກ ສ່ວນທີສາມຈະບໍ່ໄດ້ ຜົນ . ການເຂົ້າເຖິງຟາຍຈາກບ່ອນທີ່ຫ່າງໄກ ແລະ ການສົ່ງອີເມວແຈ້ງເຕືອນອາດຈະບໍ່ເຮັດວຽກເຊັ່ນກັນ. ຕ້ອງສ້າງການເຊື່ອມຕໍ່ຈາກ server ກັບອິນເຕີເນັດເພື່ອເຂົ້າເຖິງກັບຄຸນລັກສະນະທັງຫມົດ.",
    "Nextcloud 20 is the last release supporting PHP 7.2. Nextcloud 21 requires at least PHP 7.3." : "Nextcloud 20 ເປັນສະບັບສຸດທ້າຍທີ່ສະຫນັບສະຫນູນ PHP 7.2. Nextcloud 21 ຊື່ງຕ້ອງມີ PHP 7.3.",
    "The PHP OPcache module is not loaded. {linkstart}For better performance it is recommended ↗{linkend} to load it into your PHP installation." : "ໂມດູນ PHP OPcache ບໍ່ໄດ້ຖືກໂຫຼດ. {linkstart} ສໍາລັບການປະຕິບັດທີ່ດີກວ່າ ໄດ້ຮັບ ການແນະນໍາ ↗{linkend} ເພື່ອ ໂຫຼດ ມັນ ເຂົ້າ ໄປ ໃນ ການ ຕິດ ຕັ້ງ PHP ຂອງ ທ່ານ .",
    "The PHP OPcache module is not properly configured. {linkstart}For better performance it is recommended ↗{linkend} to use the following settings in the <code>php.ini</code>:" : "ໂມດູນ PHP OPcache ບໍ່ໄດ້ຕັ້ງຄ່າຢ່າງເຫມາະສົມ. {linkstart} ສໍາລັບການປະຕິບັດງານທີ່ດີກວ່າແມ່ນແນະນໍາໃຫ້ ↗{linkend} ເພື່ອໃຊ້ການຕັ້ງຄ່າດັ່ງຕໍ່ໄປນີ້ໃນ php.ini:",
    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running 'occ db:convert-filecache-bigint' those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}." : "ບາງຄໍລໍາໃນຖານຂໍ້ມູນແມ່ນຂາດການປ່ຽນ ໂຕແປໃຫຍ່ ໃຫຍ່ . ເນື່ອງຈາກວ່າການປ່ຽນ ແປງແບບ column ໃນຕາຕະລາງ ອາດຈະໃຊ້ ເວລາດົນ ທີ່ພວກເຂົາເຈົ້າບໍ່ໄດ້ ປ່ຽນແປງ ໂດຍອັດຕະໂນມັດ . ໂດຍການແລ່ນ 'occ db:convert-filecache-bigint' ຜຸ້ທີ່ກໍາລັງປ່ຽນແປງທີ່ກໍາລັງຄ້າງສາມາດນໍາໃຊ້ໄດ້ດ້ວຍມື. ການດໍາເນີນງານນີ້ຈໍາເປັນຕ້ອງໄດ້ ເຮັດ ໃນຂະນະທີ່ຕົວຢ່າງແມ່ນ offline . ສໍາລັບລາຍລະອຽດເພີ່ມເຕີມອ່ານ {linkstart}ຫນ້າເອກະສານກ່ຽວ ກັບ ↗{linkend} ນີ້.",
    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the {linkstart}documentation ↗{linkend}." : "ເພື່ອຍົກຍ້າຍໄປຖານຂໍ້ມູນອື່ນໃຊ້ເຄື່ອງມືຄໍາສັ່ງ: 'occ db:convert-type', ຫຼື ເບິ່ງ{linkstart}ເອກະສານ ↗{linkend}.",
    "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "ຊອບແວຂໍ້ມູນ ແລະ ຟາຍຂອງທ່ານອາດຈະສາມາດເຂົ້າເຖິງໄດ້ຈາກອິນເຕີເນັດ .ຟາຍ htaccess ບໍ່ໄດ້ເຮັດວຽກ . ແນະ ນໍາໃຫ້ ທ່ານຕັ້ງຄ່າ ເວັບ ໄຊ ຂອງ ທ່ານ ເພື່ອວ່າຂໍ້ມູນບໍ່ ສາ ມາດ ເຂົ້າ ເຖິງ ໄດ້ ໂດຍກົງ ອີກ ຕໍ່ ໄປ , ຫຼື ການ ເຄື່ອນ ຍ້າຍຂໍ້ ມູນ ຢູ່ ນອກຮາກຖານຂອງເອກະ ສານ web server  ໂດຍກົງ ",
    "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "ຫົວຂໍ້ \"{header}\" HTTP ບໍ່ມີ \"{expected}\". ນີ້ແມ່ນຄວາມສ່ຽງດ້ານຄວາມປອດໄພ ຫຼືຄວາມເປັນສ່ວນຕົວ, ແນະນໍາໃຫ້ປັບການຕັ້ງຄ່າຕາມນີ້.",
    "Collaboratively edit office documents." : "ຮຽບຮຽງເອກະສານຫ້ອງການຮ່ວມກັນ.",
    "Local document editing back-end used by the Collabora Online app." : "ບ່ອນເກັບເອກະສານແກ້ໄຂ back-end ທີ່ໃຊ້ໂດຍ app Collabora ອອນໄລນ໌",
    "restricted" : "ຈໍາກັດ",
    "invisible" : "ບໍ່ເຫັນ",
    "File not found" : " ບໍ່ພົບຟາຍ",
    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "ເອກະສານບໍ່ສາມາດຄົ້ນພົບໄດ້ໃນ server.  ບາງທີສ່ວນແບ່ງຖືກລຶບ ຫຼື ໄດ້ສິ້ນສຸດລົງ?",
    "More" : "ເພີ່ມເຕີມ",
    "More apps menu" : "ເມນູແອັບເພີ່ມເຕີມ",
    "Settings menu" : "ການຕັ້ງຄ່າເມນູ",
    "The password is wrong. Try again." : "ລະຫັດບໍ່ຖືກຕ້ອງ. ລອງໃໝ່ອີກຄັ້ງ.",
    "Setup two-factor authentication" : "ການຕັ້ງຄ່າຮັບຮອງການຢັ້ງຢືນສອງຄັ້ງ"
},
"nplurals=1; plural=0;");
